@@ -2,18 +2,16 @@ package File::Remove;
 
 use 5.005;
 use strict;
-use vars qw(@EXPORT_OK @ISA $VERSION $debug $unlink $rmdir);
-BEGIN {
-	$VERSION   = '1.41';
-	@ISA       = qw(Exporter);
-	@EXPORT_OK = qw(remove rm trash); # nothing by default :)
 
-	# Booleanise the debug flag
-	$debug = !! $debug;
+use vars qw{$VERSION @ISA @EXPORT_OK};
+use vars qw{$debug $unlink $rmdir};
+BEGIN {
+	$VERSION   = '1.42';
+	@ISA       = qw{ Exporter};
+	@EXPORT_OK = qw{ remove rm clear trash };
 }
 
-# If we ever need a Mac::Glue object,
-# we will want to cache it.
+# If we ever need a Mac::Glue object we will want to cache it.
 my $glue;
 
 use File::Spec ();
@@ -26,15 +24,19 @@ sub expand (@) {
 
 # $debug variable must be set before loading File::Remove.
 # Convert to a constant to allow debugging code to be pruned out.
-use constant DEBUG => $debug;
+use constant DEBUG    => !! $debug;
 
 # Are we on VMS?
 # If so copy File::Path and assume VMS::Filespec is loaded
-use constant IS_VMS   => $^O eq 'VMS';
+use constant IS_VMS   => !! ( $^O eq 'VMS' );
+
+# Are we on Mac?
+# If so we'll need to do some special trash work
+use constant IS_MAC   => !! ( $^O eq 'darwin' );
 
 # Are we on Win32?
 # If so write permissions does not imply deletion permissions
-use constant IS_WIN32 => $^O eq 'MSWin32';
+use constant IS_WIN32 => !! ( $^O =~ /^MSWin/ or $^O eq 'cygwin' );
 
 
 
@@ -43,12 +45,34 @@ use constant IS_WIN32 => $^O eq 'MSWin32';
 #####################################################################
 # Main Functions
 
+my @END_DELETE = ();
+
+sub clear (@) {
+	my @files = expand( @_ );
+
+	# Do the initial deletion
+	foreach my $file ( @files ) {
+		next unless -e $file;
+		remove( \1, $file );
+	}
+
+	# Delete again at END-time
+	push @END_DELETE, @files;
+}
+
+END {
+	foreach my $file ( @END_DELETE ) {
+		next unless -e $file;
+		remove( \1, $file );
+	}
+}
+
 # acts like unlink would until given a directory as an argument, then
 # it acts like rm -rf ;) unless the recursive arg is zero which it is by
 # default
 sub remove (@) {
 	my $recursive = (ref $_[0] eq 'SCALAR') ? shift : \0;
-	my @files     = expand @_;
+	my @files     = expand(@_);
 
 	# Iterate over the files
 	my @removes;
@@ -56,7 +80,7 @@ sub remove (@) {
                 # need to check for symlink first
                 # could be pointing to nonexisting/non-readable destination
 		if ( -l $path ) {
-			print "link: $path\n" if $debug;
+			print "link: $path\n" if DEBUG;
 			if ( $unlink ? $unlink->($path) : unlink($path) ) {
 				push @removes, $path;
 			}
@@ -147,20 +171,26 @@ sub trash (@) {
 		$unlink = $options{unlink};
 		$rmdir  = $options{rmdir};
 
-	} elsif ( $^O eq 'cygwin' || $^O =~ /^MSWin/ ) {
+	} elsif ( IS_WIN32 ) {
+		local $@;
 		eval 'use Win32::FileOp ();';
 		die "Can't load Win32::FileOp to support the Recycle Bin: \$@ = $@" if length $@;
 		$unlink = \&Win32::FileOp::Recycle;
 		$rmdir  = \&Win32::FileOp::Recycle;
 
-	} elsif ( $^O eq 'darwin' ) {
+	} elsif ( IS_MAC ) {
 		unless ( $glue ) {
+			local $@;
 			eval 'use Mac::Glue ();';
 			die "Can't load Mac::Glue::Finder to support the Trash Can: \$@ = $@" if length $@;
 			$glue = Mac::Glue->new('Finder');
 		}
 		my $code = sub {
-			my @files = map { Mac::Glue::param_type(Mac::Glue::typeAlias() => $_) } @_;
+			my @files = map {
+				Mac::Glue::param_type(
+					Mac::Glue::typeAlias() => $_
+				)
+			} @_;
 			$glue->delete(\@files);
 		};
 		$unlink = $code;
@@ -168,6 +198,7 @@ sub trash (@) {
 	} else {
 		die "Support for trash() on platform '$^O' not available at this time.\n";
 	}
+
 	goto &remove;
 }
 
@@ -187,19 +218,19 @@ File::Remove - Remove files and directories
 
 =head1 SYNOPSIS
 
-    use File::Remove qw(remove);
+    use File::Remove 'remove';
 
     # removes (without recursion) several files
-    remove qw( *.c *.pl );
+    remove( '*.c', '*.pl' );
 
     # removes (with recursion) several directories
-    remove \1, qw( directory1 directory2 ); 
+    remove( \1, qw{directory1 directory2} ); 
 
     # removes (with recursion) several files and directories
-    remove \1, qw( file1 file2 directory1 *~ );
+    remove( \1, qw{file1 file2 directory1 *~} );
 
     # trashes (with support for undeleting later) several files
-    trash qw( *~ );
+    trash( '*~' );
 
 =head1 DESCRIPTION
 
@@ -214,9 +245,7 @@ hashref.
 
 =head1 SUBROUTINES
 
-=over 4
-
-=item remove
+=head2 remove
 
 Removes files and directories.  Directories are removed recursively like
 in B<rm -rf> if the first argument is a reference to a scalar that
@@ -228,12 +257,20 @@ In list context it returns a list of files/directories removed, in
 scalar context it returns the number of files/directories removed.  The
 list/number should match what was passed in if everything went well.
 
-=item rm
+=head2 rm
 
 Just calls B<remove>.  It's there for people who get tired of typing
 B<remove>.
 
-=item trash
+=head2 clear
+
+The C<clear> function is a version of C<remove> designed for
+use in test scripts. It takes a list of paths that it will both
+initially delete during the current test run, and then further
+flag for deletion at END-time as a convenience for the next test
+run.
+
+=head2 trash
 
 Removes files and directories, with support for undeleting later.
 Accepts an optional "other platforms" hashref, passing the remaining
@@ -260,12 +297,13 @@ will be called with the filenames that are to be deleted.
 
 =back
 
-=back
+=head1 SUPPORT
 
-=head1 BUGS
+Bugs should always be submitted via the CPAN bug tracker
 
-See L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Remove> for the
-up-to-date bug listing.
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Remove>
+
+For other issues, contact the maintainer.
 
 =head1 AUTHOR
 
